about summary refs log tree commit diff stats
diff options
context:
space:
mode:
-rw-r--r--core/scripts/iptables.sh13
-rw-r--r--tools/conf/etc/X11/xinit/xinitrc (renamed from tools/conf/usr/etc/X11/xinit/xinitrc)10
-rw-r--r--tools/conf/etc/skel/.xinitrc12
-rw-r--r--tools/qemu.html2
-rw-r--r--tools/scripts/pkgmk-test.conf2
-rw-r--r--tools/x.html116
6 files changed, 92 insertions, 63 deletions
diff --git a/tools/conf/usr/etc/X11/xinit/xinitrc b/tools/conf/etc/X11/xinit/xinitrc
index 36b3c3c..2607046 100644
--- a/tools/conf/usr/etc/X11/xinit/xinitrc
+++ b/tools/conf/etc/X11/xinit/xinitrc
@@ -2,13 +2,14 @@
 
 userresources=$HOME/.Xresources
 usermodmap=$HOME/.Xmodmap
-sysresources=/usr/etc/X11/xinit/.Xresources
-sysmodmap=/usr/etc/X11/xinit/.Xmodmap
+sysresources=/etc/X11/xinit/.Xresources
+sysmodmap=/etc/X11/xinit/.Xmodmap
 
 # merge in defaults and keymaps
 
 if [ -f $sysresources ]; then
     xrdb -merge $sysresources
+
 fi
 
 if [ -f $sysmodmap ]; then
@@ -17,6 +18,7 @@ fi
 
 if [ -f "$userresources" ]; then
     xrdb -merge "$userresources"
+
 fi
 
 if [ -f "$usermodmap" ]; then
@@ -25,8 +27,8 @@ fi
 
 # start some nice programs
 
-if [ -d /usr/etc/X11/xinit/xinitrc.d ] ; then
- for f in /usr/etc/X11/xinit/xinitrc.d/?*.sh ; do
+if [ -d /etc/X11/xinit/xinitrc.d ] ; then
+ for f in /etc/X11/xinit/xinitrc.d/?*.sh ; do
   [ -x "$f" ] && . "$f"
  done
  unset f
diff --git a/tools/conf/etc/skel/.xinitrc b/tools/conf/etc/skel/.xinitrc
index c331d37..6ccd340 100644
--- a/tools/conf/etc/skel/.xinitrc
+++ b/tools/conf/etc/skel/.xinitrc
@@ -1,11 +1,13 @@
+## Start the window manager
 
-#xrandr --output eDP1 --mode 1024x768
+xrandr -s 1366x768
 #xrandr --dpi 100
+#xrandr --output eDP1 --mode 1366x768
 #xgamma -gamma 0.8
-syndaemon -d
-#
-## Start the window manager
+#syndaemon -d
+setxkbmap dvorak
 
-#exec dwm
 #exec openbox-session
+#exec dwm
 exec spectrwm
+#exec start-mate
diff --git a/tools/qemu.html b/tools/qemu.html
index e180ed4..a6621a1 100644
--- a/tools/qemu.html
+++ b/tools/qemu.html
@@ -335,7 +335,7 @@
         <p>Update grub configuration on guest machine;</p>
 
         <pre>
-        # update-grub
+        # grub-mkconfig -o /boot/grub/grub.cfg
         </pre>
 
         <h3 id="sound">4.2. Guest Sound</h3>
diff --git a/tools/scripts/pkgmk-test.conf b/tools/scripts/pkgmk-test.conf
index 6dec896..715ac01 100644
--- a/tools/scripts/pkgmk-test.conf
+++ b/tools/scripts/pkgmk-test.conf
@@ -4,7 +4,7 @@
 
 source /etc/pkgmk.conf
 
-PKGMK_SOURCE_MIRRORS=()
+#PKGMK_SOURCE_MIRRORS=()
 PKGMK_SOURCE_DIR="$PWD"
 PKGMK_PACKAGE_DIR="$PWD"
 PKGMK_WORK_DIR="$PWD/work"
diff --git a/tools/x.html b/tools/x.html
index cbc9d3e..913f1f0 100644
--- a/tools/x.html
+++ b/tools/x.html
@@ -13,6 +13,9 @@
 
         <h2>Install</h2>
 
+
+        <h3>Xorg</h3>
+
         <pre>
         $ sudo prt-get depinst xorg-server \
              xorg-xinit \
@@ -28,7 +31,7 @@
              xkeyboard-config
         </pre>
 
-        <h2>Fonts</h2>
+        <h3>Fonts</h3>
 
         <pre>
         $ sudo prt-get depinst xorg-font-util \
@@ -50,35 +53,76 @@
         $ prt-get depinst otf-sourcecode
         </pre>
 
+        <h3>Utilities</h3>
+
+        <pre>
+        $ sudo prt-get depinst \
+            alsa-utils \
+            libdrm \
+            mesa3d \
+            ffmpeg \
+            gstreamer \
+            gstreamer-vaapi \
+            gst-plugins-base \
+            gst-plugins-good \
+            gst-plugins-bad \
+            gst-plugins-ugly \
+            cmus \
+            dmenu \
+            st \
+            gparted \
+            gimp \
+            libreoffice \
+            ca-certificates \
+	    linux-pam \
+	    gstreamer \
+	    libgd \
+            icu \
+	    syndaemon
+        </pre>
+
+        <h3>Window Managers</h3>
+
+	<pre>
+        $ sudo prt-get depinst \
+		openbox \
+		dwm \
+         	spectrwm \
+	 	mate
+	</pre>
+
         <h2>Configure</h2>
 
-        <p>Example of <a href="conf/etc/skel/.xinitrc">/etc/skel/.xinitrc</a>;</p>
+        <h3>Local xinitrc</h3>
 
-        <pre>
-        #xrandr --output eDP1 --mode 1024x768
-        #xrandr --dpi 100
-        #xgamma -gamma 0.8
-        syndaemon -d
-        #
-        ## Start the window manager
+        <p>Local xinitrc configuration: <a href="conf/etc/skel/.xinitrc">/etc/skel/.xinitrc</a>;</p>
 
-        #exec dwm
-        #exec twm
-        #exec openbox-session
-        exec spectrwm
+        <pre>
+	## Start the window manager
+
+	xrandr -s 1366x768
+	#xrandr --dpi 100
+	#xrandr --output eDP1 --mode 1366x768
+	#xgamma -gamma 0.8
+	#syndaemon -d
+	setxkbmap dvorak
+
+	#exec openbox-session
+	#exec dwm
+	exec spectrwm
+	#exec start-mate
         </pre>
 
-
-        <p>Example of
-        <a href="conf/usr/etc/X11/xinit/xinitrc">/usr/etc/X11/xinit/xinitrc</a>;</p>
+        <h3>Global xinitrc</h3>
+        <p>Global xinitrc configuration: <a href="conf/etc/X11/xinit/xinitrc">/usr/etc/X11/xinit/xinitrc</a>;</p>
 
         <pre>
         #!/bin/sh
 
         userresources=$HOME/.Xresources
         usermodmap=$HOME/.Xmodmap
-        sysresources=/usr/etc/X11/xinit/.Xresources
-        sysmodmap=/usr/etc/X11/xinit/.Xmodmap
+        sysresources=/etc/X11/xinit/.Xresources
+        sysmodmap=/etc/X11/xinit/.Xmodmap
 
         # merge in defaults and keymaps
 
@@ -102,15 +146,17 @@
 
         # start some nice programs
 
-        if [ -d /usr/etc/X11/xinit/xinitrc.d ] ; then
-         for f in /usr/etc/X11/xinit/xinitrc.d/?*.sh ; do
+        if [ -d /etc/X11/xinit/xinitrc.d ] ; then
+         for f in /etc/X11/xinit/xinitrc.d/?*.sh ; do
           [ -x "$f" ] && . "$f"
          done
          unset f
         fi
         </pre>
 
-        <p><a href="conf/etc/X11/xorg.conf.d/10-keyboard.conf">/etc/X11/xorg.conf.d/10-keyboard.conf</a></p>
+        <h3>Global keyboard config </h3>
+
+	<p>Xorg global default keyboard configuration; <a href="conf/etc/X11/xorg.conf.d/10-keyboard.conf">/etc/X11/xorg.conf.d/10-keyboard.conf</a></p>
 
         <pre>
          Section "InputClass"
@@ -120,7 +166,7 @@
          EndSection
         </pre>
 
-        <p><a href="/etc/X11/xorg.conf.d/50-synaptics.conf">/etc/X11/xorg.conf.d/50-synaptics.conf</a></p>
+	<p>Xorg synaptics configuration; <a href="/etc/X11/xorg.conf.d/50-synaptics.conf">/etc/X11/xorg.conf.d/50-synaptics.conf</a></p>
 
         <pre>
         # Example xorg.conf.d snippet that assigns the touchpad driver
@@ -180,32 +226,6 @@
 
         <h2>Window Managers</h2>
 
-
-        <pre>
-        $ sudo prt-get depinst \
-            alsa-utils \
-            libdrm \
-            mesa3d \
-            ffmpeg \
-            gstreamer \
-            gstreamer-vaapi \
-            gst-plugins-base \
-            gst-plugins-good \
-            gst-plugins-bad \
-            gst-plugins-ugly \
-            cmus \
-            adwaita-icon-theme \
-            dmenu \
-            st \
-            conky \
-            dillo \
-            spectrwm \
-            gparted \
-            gimp \
-            libreoffice \
-            epiphany
-        </pre>
-
         <h3>Spectrwm</h3>
 
         <p>Edit ~/.spectrwm.conf</p>
diff --git a/core/scripts/iptables.sh b/core/scripts/iptables.sh
index db1078d..0516d94 100644
--- a/core/scripts/iptables.sh
+++ b/core/scripts/iptables.sh
@@ -271,9 +271,11 @@ case $TYPE in
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap3 --physdev-out tap2 -s ${BR_NET} -d ${BR_NET} -j ACCEPT
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap2 --physdev-out tap3 -s ${BR_NET} -d ${BR_NET} -j ACCEPT
 
         # Tap1 can access external http
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap1 -j cli_http_in
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap1 --physdev-out ${PUB_IF} -j cli_http_out
+        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap3 -j cli_http_in
+        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap3 --physdev-out ${PUB_IF} -j cli_http_out
 
         ####### Forward TAP2 ssh, http and https  ######
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap2 -j srv_ssh_in
@@ -290,12 +292,15 @@ case $TYPE in
         #        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap2 --physdev-out ${PUB_IF} -j srv_dhcp
         #        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap2 -j srv_dhcp
 
-        # Tap1 and Tap2 can access external https
+        # Tap1, Tap2 and Tap3 can access external https
+        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap1 --physdev-out ${PUB_IF} -j cli_https_out
+        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap1 -j cli_https_in
+
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap2 --physdev-out ${PUB_IF} -j cli_https_out
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap2 -j cli_https_in
 
-        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap1 --physdev-out ${PUB_IF} -j cli_https_out
-        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap1 -j cli_https_in
+        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap3 --physdev-out ${PUB_IF} -j cli_https_out
+        $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap3 -j cli_https_in
 
         #Less noise
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} -p udp --dport 519 --sport 520 -j DROP
@@ -271,9 +271,11 @@ case $TYPE in
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap2 --physdev-out tap3 -s ${BR_NET} -d ${BR_NET} -j ACCEPT
 
-        # Tap1 can access external http
+        # Tap1 and Tap3 can access external http
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in ${PUB_IF} --physdev-out tap1 -j cli_http_in
         $IPT -A FORWARD -i ${BR_IF} -o ${BR_IF} -m physdev --physdev-in tap1 --physdev-out ${PUB_IF} -j cli_http_out